@@ -3,9 +3,9 @@ package SimpleR::Reshape;
 
 require Exporter;
 @ISA    = qw(Exporter);
-@EXPORT = qw(read_table write_table melt cast merge split_file arrange);
+@EXPORT = qw(read_table write_table melt cast merge merge_file split_file arrange);
 
-our $VERSION     = 0.07;
+our $VERSION     = 0.08;
 our $DEFAULT_SEP = ',';
 
 use B::Deparse ();
@@ -260,6 +260,53 @@ sub merge {
     return \@result;
 }
 
+sub merge_file {
+	# $y left join $x , with some coulumn
+	my ( $x, $y, %opt ) = @_;
+	$opt{default_cell_value} //= 0;
+	$opt{sep} //= ',';
+	$opt{merge_file} ||= "$y.merge";
+
+	my $x_raw = {
+		by    => $opt{by_x} || $opt{by},
+		value => $opt{value_x} || $opt{value} ,
+	};
+	my %mem_x;
+	read_table($x, 
+			%opt, 
+			return_arrayref=>0, 
+			conv_sub => sub {
+			my ($r) = @_;
+			my $cut = join( $opt{sep}, @{$r}[@{$x_raw->{by}}] );
+			my @vs = map {
+			$r->[$_] // $opt{default_cell_value}
+			} @{$x_raw->{value}};
+			$mem_x{$cut} = \@vs;
+			});
+
+	my $y_raw = {
+		by    => $opt{by_y} || $opt{by},
+		value => $opt{value_y} || $opt{value} ,
+	};
+
+	read_table($y, 
+			%opt,
+			write_file => $opt{merge_file}, 
+			return_arrayref=>0, 
+			conv_sub => sub {
+			my ($d) = @_;
+			my $cut = join( $opt{sep}, @{$d}[@{$y_raw->{by}}] );
+			my @vs = map {
+			$d->[$_] // $opt{default_cell_value}
+			} @{$y_raw->{value}};
+			push @vs, @{$mem_x{$cut}};
+			return \@vs;
+			}, 
+		  );
+
+	return $opt{merge_file};
+}
+
 sub split_file {
     my ( $f, %opt ) = @_;
     $opt{split_file} ||= $f;
@@ -277,7 +324,7 @@ sub split_file {
         my $k = join( $opt{sep}, map_arrayref_value( $opt{id}, $r ) );
         $k =~ s#[\\\/,]#-#g;
 
-        if ( !exists $exist_fh{$k} ) {
+        if ( ! exists $exist_fh{$k} ) {
             my $file = "$opt{split_file}.".encode(locale => $k);
             my $write_format = $opt{charset} ? ">:$opt{charset}" : ">";
             open $exist_fh{$k}, $write_format, $file;
